@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12001 2020-03-24 16:45:06Z Trista $
+# $Id: __init__.py 12062 2020-04-09 19:13:28Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Trista $
-# $Date: 2020-03-25 01:45:06 +0900 (週三, 25 三月 2020) $
-# $Revision: 12001 $
+# $Author: Lavender $
+# $Date: 2020-04-10 04:13:28 +0900 (週五, 10 四月 2020) $
+# $Revision: 12062 $
 
 from django.conf import settings as _settings
 from django.utils.translation import ugettext_lazy as _
@@ -91,10 +91,13 @@ class settings(object):
 
 
 
-    formTemplates = _settings.DJANGOCMS_FORMS_TEMPLATES
-    filteredTemplates = [t for t in CALL_TO_ACTION_FORM_TEMPLATES  if t not in _settings.DJANGOCMS_FORMS_TEMPLATES]
-    
-    _settings.DJANGOCMS_FORMS_TEMPLATES = formTemplates + filteredTemplates
+    if hasattr(_settings, 'DJANGOCMS_FORMS_TEMPLATES'):
+        formTemplates = _settings.DJANGOCMS_FORMS_TEMPLATES
+        filteredTemplates = [t for t in CALL_TO_ACTION_FORM_TEMPLATES  if t not in _settings.DJANGOCMS_FORMS_TEMPLATES]
+        
+        _settings.DJANGOCMS_FORMS_TEMPLATES = formTemplates + filteredTemplates
+    else:
+        _settings.DJANGOCMS_FORMS_TEMPLATES = [t for t in CALL_TO_ACTION_FORM_TEMPLATES]
 
 
 
