@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 12330 2020-06-08 20:10:48Z Trista $
+# $Id: cms_plugins.py 12420 2020-07-23 08:06:48Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Trista $
-# $Date: 2020-06-09 04:10:48 +0800 (Tue, 09 Jun 2020) $
-# $Revision: 12330 $
+# $Author: Lavender $
+# $Date: 2020-07-23 17:06:48 +0900 (週四, 23 七月 2020) $
+# $Revision: 12420 $
 
 import datetime
 
@@ -29,6 +29,7 @@ from django.utils.translation import ugettext as _
 from django.template.loader import select_template
 from django.template.response import SimpleTemplateResponse
 from django.db.models import Q
+from django.conf.urls.static import static
 from djangocms_forms.models import Form, FormDefinition
 from djangocms_forms.cms_plugins import FormFieldInline
 from djangocms_forms.forms import FormBuilder
