@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 12330 2020-06-08 20:10:48Z Trista $
+# $Id: views.py 12420 2020-07-23 08:06:48Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Trista $
-# $Date: 2020-06-09 04:10:48 +0800 (Tue, 09 Jun 2020) $
-# $Revision: 12330 $
+# $Author: Lavender $
+# $Date: 2020-07-23 17:06:48 +0900 (週四, 23 七月 2020) $
+# $Revision: 12420 $
 
 import datetime
 import hashlib
@@ -47,6 +47,7 @@ from django.urls import reverse
 from django.http import (
     HttpResponseRedirect,
     HttpResponsePermanentRedirect,
+    Http404,
 )
 
 from djangocms_forms.models import FormDefinition
