@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_dumpdata.py 12415 2020-07-23 04:08:00Z Lavender $
+# $Id: cms_dumpdata.py 12436 2020-07-30 08:41:42Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-07-23 12:08:00 +0800 (Thu, 23 Jul 2020) $
-# $Revision: 12415 $
+# $Date: 2020-07-30 17:41:42 +0900 (週四, 30 七月 2020) $
+# $Revision: 12436 $
 
 import os
 import sys
@@ -85,22 +85,24 @@ class Command(BaseCommand):
             os.system(
                 "%s manage.py dumpdata cms.Treenode > treenodeData.json" %  
                 sys.executable)
-             
+                
+            excludeApps = [
+                'auth',
+                'sites',
+                'filer',
+                'contenttypes',
+                'cms.Treenode',
+            ]
+            
             if "Zephyrus.statistics" in settings.INSTALLED_APPS:
-                os.system(
-                    ("%s manage.py dumpdata "
-                     "-e auth -e sites -e filer -e "
-                     "contenttypes -e cms.Treenode -e statistics"
-                     "> otherData.json") % 
-                     sys.executable)
-            else:
-                os.system(
-                    ("%s manage.py dumpdata "
-                     "-e auth -e sites -e filer -e "
-                     "contenttypes -e cms.Treenode"
-                     "> otherData.json") % 
-                     sys.executable)
-        
+                excludeApps.append("statistics")
+            if "Iuno.redirect" in settings.INSTALLED_APPS:
+                excludeApps.append("redirect")
+                
+            excludeStr = "-e %s" % " -e ".join(excludeApps)
+            
+            os.system("%s manage.py dumpdata %s > otherData.json" % (sys.executable, excludeStr))
+            
             with open('authData.json') as f:
                 content = f.read()
                 authData = json.loads(content[content.index('['):])
