@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: get_template.py 11436 2019-04-10 17:56:15Z Lavender $
+# $Id: get_template.py 11677 2019-08-16 00:30:37Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-11 01:56:15 +0800 (週四, 11 四月 2019) $
-# $Revision: 11436 $
+# $Date: 2019-08-16 09:30:37 +0900 (週五, 16 八月 2019) $
+# $Revision: 11677 $
 
 import os
 import shutil
@@ -75,6 +75,7 @@ class Command(BaseCommand):
                 logger.info("Copy images folder to root.")
 
             copyHtml = False
+            templateRootPath = None 
             for root, dirs, files in os.walk(path):
                 if 'info.json' in files:
                     jsonPath = os.path.join(root, 'info.json')           
@@ -93,27 +94,50 @@ class Command(BaseCommand):
                                  "but have %s") % (path, f))
                 
                 if copyHtml:
-                    for fileName in files:
-                        filePath = os.path.join(root, fileName)
-                        if fileName.endswith('.html'):
-                            dst = os.path.join(TEMPLATES_DIR_PATH, fileName)
-                            shutil.copyfile(filePath, dst)
-                            logger.info(
-                                'Copy %s to templates folder.' % fileName)
-                        else:
-                            dst = os.path.join(STATIC_DIR_PATH, fileName)
-                            shutil.copyfile(filePath, dst)
-                            logger.info('Copy %s to static folder.' % fileName)
-                    for dirName in dirs:
-                        dirPath = os.path.join(root, dirName)
-                        dst = os.path.join(STATIC_DIR_PATH, dirName)
-                        shutil.copytree(dirPath, dst)
-                        logger.info('Copy %s to static folder.' % dirName)
+                    templateRootPath = root
                     break
+                    
             if not copyHtml:
                 logger.error("'%s' not have html file" % path)
                 raise RuntimeError("'%s' not have html file" % path)
-
+            else:
+                for root, dirs, files in os.walk(templateRootPath):
+                    if path.endswith('/') or path.endswith('\\'):
+                        relatedPath = root.replace(path, '')
+                    else:
+                        # 去掉第一個 / or \
+                        relatedPath = root.replace(path, '')[1:]
+                    
+                    for fileName in files:
+                        filePath = os.path.join(root, fileName)
+                        
+                        if fileName.endswith('.html'):
+                            dstDirPath = os.path.join(
+                                TEMPLATES_DIR_PATH, relatedPath)
+                            logger.info(
+                                'Copy %s to templates folder.' % fileName)
+                        else:
+                            dstDirPath = os.path.join(
+                                STATIC_DIR_PATH, relatedPath)
+                            logger.info('Copy %s to static folder.' % fileName)
+                            
+                        dirList = [dstDirPath,]
+                            
+                        dirPath = dstDirPath
+                        while True:
+                            dirPath = os.path.dirname(dirPath)
+                            if not os.path.exists(dirPath):
+                                dirList.append(dirPath)
+                            else:
+                                break
+                        
+                        dirList.reverse()
+                        for d in dirList:
+                            if not os.path.isdir(d):
+                                os.mkdir(d)
+                        dst =  os.path.join(dstDirPath, fileName)
+                        shutil.copyfile(filePath, dst)
+                        
             logger.info('-----All OK!-----')
         except Exception as e:
             logger.error("get_template error:%s" % e)
