@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: pluginize.py 12415 2020-07-23 04:08:00Z Lavender $
+# $Id: pluginize.py 12449 2020-08-06 06:53:34Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-07-23 12:08:00 +0800 (Thu, 23 Jul 2020) $
-# $Revision: 12415 $
+# $Date: 2020-08-06 15:53:34 +0900 (週四, 06 八月 2020) $
+# $Revision: 12449 $
 
 import os
 import json
@@ -98,7 +98,7 @@ class Attr(object):
         self.name = name
         self.value = value 
 
-class Tag(object):
+class Tag2(object):
     def __init__(self, tagName, placeholderName, md5, attrList):
         self.tag = tagName
         self.name = placeholderName
@@ -156,6 +156,12 @@ class Placeholder2(Placeholder):
             if not hasPlugin:
                 string = content.lower().strip()
                 
+                string = '''
+                <img scr='data:   '>
+                <img scr='data:'>
+                <img scr='data:'>
+                '''
+                
                 isOutSideTag = False
                 if string.startswith('<') and string.endswith('>'):
                     isOutSideTag = True
@@ -192,7 +198,7 @@ class Placeholder2(Placeholder):
                         
                         
                         tagList.append(
-                            Tag('a', placeholder.slot, 
+                            Tag2('a', placeholder.slot, 
                             hashlib.md5(
                                 toBytes(placeholder.slot)).hexdigest(), attrList))
                     else:
@@ -219,7 +225,7 @@ class Placeholder2(Placeholder):
                     
                     
                     tagList.append(
-                        Tag('img', placeholder.slot, 
+                        Tag2('img', placeholder.slot, 
                         hashlib.md5(
                             toBytes(placeholder.slot)).hexdigest(), attrList))
                     
@@ -269,8 +275,11 @@ class Placeholder2(Placeholder):
                             placeholder=placeholder,
                             language=Placeholder2.lang,
                             body=content, plugin_type='TextPlugin')
-                    except Exception as e:
-                        logger.error("Can't add content to text plugin: %s\n%s" % (str(e), content))
+                    except AttributeError as e:
+                        if "data:" in content:
+                            logger.error("Can't add content to text plugin: %s\n%s" % (str(e), content))
+                        else:
+                            raise
 
 class Command(BaseCommand):
     
