@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11629 2019-06-11 17:44:34Z Lavender $
+# $Id: views.py 12419 2020-07-23 07:57:14Z Casey $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,14 +11,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2019-06-12 02:44:34 +0900 (週三, 12 六月 2019) $
-# $Revision: 11629 $
+# $Author: Casey $
+# $Date: 2020-07-23 16:57:14 +0900 (週四, 23 七月 2020) $
+# $Revision: 12419 $
 
 import json
 import six
 import urllib
 
+import django
 from django.views.generic import View, FormView
 from django.contrib import messages
 from django.conf import settings
@@ -35,6 +36,9 @@ from Iuppiter.Encoding import utf8
 from Zephyrus.comment.models import Comment, CommentPlugin
 from Zephyrus.comment.forms import CommentForm
 
+DJANGO_VERSION = (django.VERSION[0] * 10000 + django.VERSION[1] * 100 +
+                  django.VERSION[2])
+
 class CommentView(FormView): 
 
     form_class = CommentForm
@@ -43,24 +47,45 @@ class CommentView(FormView):
         # create comment
         url = self.request.POST.get('url')
         message = self.request.POST.get('message')
-        if self.request.user.is_anonymous():
-            email = self.request.POST.get('email')
-            comment = Comment(
-                url=url,
-                user=None,
-                email=email,
-                message=message,
-            )
-            username = email
-        else:
-            user = self.request.user
-            comment = Comment(
-                url=url,
-                user=user,
-                email=None,
-                message=message,
-            )
-            username = user.username
+        
+        if DJANGO_VERSION < 20000: # 2.0.0
+            if self.request.user.is_anonymous():
+                email = self.request.POST.get('email')
+                comment = Comment(
+                    url=url,
+                    user=None,
+                    email=email,
+                    message=message,
+                )
+                username = email
+            else:
+                user = self.request.user
+                comment = Comment(
+                    url=url,
+                    user=user,
+                    email=None,
+                    message=message,
+                )
+                username = user.username
+        else: 
+            if self.request.user.is_anonymous:
+                email = self.request.POST.get('email')
+                comment = Comment(
+                    url=url,
+                    user=None,
+                    email=email,
+                    message=message,
+                )
+                username = email
+            else:
+                user = self.request.user
+                comment = Comment(
+                    url=url,
+                    user=user,
+                    email=None,
+                    message=message,
+                )
+                username = user.username
         comment.save()
         
         # sand mail
