@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12251 2020-05-20 19:31:27Z Lavender $
+# $Id: __init__.py 12357 2020-06-18 00:42:10Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-05-21 04:31:27 +0900 (週四, 21 五月 2020) $
-# $Revision: 12251 $
+# $Date: 2020-06-18 09:42:10 +0900 (週四, 18 六月 2020) $
+# $Revision: 12357 $
 
 import json
 import requests
@@ -35,7 +35,7 @@ else:
 
 class Settings(object):
     # Facebook Nuwa Blog APP
-    ZEPHYRUS_FACEBOOK_DEFAULT_GET_ACCESS_TOKEN_URL = "https://lavender.nuwainfo.com:12345"
+    ZEPHYRUS_FACEBOOK_DEFAULT_GET_ACCESS_TOKEN_URL = "https://www.nuwainfo.com"
     ZEPHYRUS_FACEBOOK_DEFAULT_SECRET_KEY = "k*ohwp_!xr!rz*+6b2fpff%&5tw!nyh__^#y0%w#53k11#nh9p"
     ZEPHYRUS_FACEBOOK_DEFAULT_PASSWORD = "@%)@5529"
     ZEPHYRUS_FACEBOOK_DEFAULT_APP_ID = "1435073943305111"
