@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 11055 2018-05-14 09:46:32Z Lavender $
+# $Id: admin.py 11977 2020-03-16 18:37:48Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,12 +12,13 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-05-14 17:46:32 +0800 (週一, 14 五月 2018) $
-# $Revision: 11055 $
+# $Date: 2020-03-17 03:37:48 +0900 (週二, 17 三月 2020) $
+# $Revision: 11977 $
 
 from django.contrib import admin
+from solo.admin import SingletonModelAdmin
 
-from Zephyrus.facebook.models import FacebookFan, FacebookPhoto
+from Zephyrus.facebook.models import FacebookFan, FacebookPhoto, FacebookSettings
 
 class FacebookFanAdmin(admin.ModelAdmin):
     list_display = (
@@ -32,3 +33,4 @@ class FacebookPhotoAdmin(admin.ModelAdmin):
 
 admin.site.register(FacebookFan, FacebookFanAdmin)
 admin.site.register(FacebookPhoto, FacebookPhotoAdmin)
+admin.site.register(FacebookSettings, SingletonModelAdmin)
\ No newline at end of file
